package me.icymint.libra.sas.scanner;

import me.icymint.libra.sas.SasExecutorService;
import me.icymint.libra.sas.config.SasConfig;
import me.icymint.libra.sas.exception.SasAbortException;
import me.icymint.libra.sas.exception.SasCacheFileLockedException;
import me.icymint.libra.sas.exception.SasInterruptException;
import me.icymint.libra.sas.exception.SasNotRunException;
import me.icymint.libra.sas.exception.SasRunErrorException;

/**
 * SAS执行的扫描器，用于实时的监控
 * 
 * @author Daniel
 * @datetime 2012-10-22下午2:05:04
 * 
 */
public interface Scanner<V, T extends SasConfig> extends SasExecutorService {
	/**
	 * 结束扫描过程。
	 * 
	 * @param config
	 * @throws SasRunErrorException
	 */
	void finallizeScanner(T config) throws SasRunErrorException;

	/**
	 * 初始化扫描器，一般是初始化临时目录，
	 * 
	 * @throws SasNotRunException
	 * @throws SasCacheFileLockedException
	 */
	void initializeScanner(T config) throws SasNotRunException,
			SasCacheFileLockedException;

	/**
	 * 获取SAS执行代码。
	 * 
	 * @return
	 */
	String sas();

	/**
	 * 扫描过程。
	 * 
	 * @param config
	 * @throws SasAbortException
	 */
	void scan(T config) throws SasInterruptException, SasRunErrorException,
			SasAbortException;

	/**
	 * 结果获取流。
	 * 
	 * @throws InterruptedException
	 */
	V take() throws InterruptedException;
}
